# luxsci

Luxsci - JavaScript client for luxsci
For a technical overview, see [LuxSci API Mechanics Guide](/rest-api/mechanics.html)  Return to [The API Guide](/rest-api.html)
This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: v2024.2.1
- Package version: v2024.2.1
- Build package: io.swagger.codegen.v3.generators.javascript.JavaScriptClientCodegen

## Installation

### For [Node.js](https://nodejs.org/)

#### npm

From your project, install tarballed package found in this directory:

```shell
npm install {path to this directory}/luxsci-2024.2.1.tgz --save

```

### For browser

The library also works in the browser environment via npm and [browserify](http://browserify.org/). After following
the above steps with Node.js and installing browserify with `npm install -g browserify`,
perform the following (assuming *main.js* is your entry file):

```shell
browserify main.js > bundle.js
```

Then include *bundle.js* in the HTML pages.

### Webpack Configuration

Using Webpack you may encounter the following error: "Module not found: Error:
Cannot resolve module", most certainly you should disable AMD loader. Add/merge
the following section to your webpack config:

```javascript
module: {
  rules: [
    {
      parser: {
        amd: false
      }
    }
  ]
}
```

## Getting Started

Please follow the [installation](#installation) instruction and execute the following JS code:

```javascript
var Luxsci = require('luxsci');

const secret_key = "SECRET_KEY";
const token = "TOKEN";
const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
var api = luxsciClient.AuthenticationApi

var opts = { 
  'body': new Luxsci.AuthBody() // {AuthBody} 
};
api.authentication(opts).then(function(data) {
  console.log('API called successfully. Returned data: ' + data);
}, function(error) {
  console.error(error);
});

```

## File Attachments
The SDK's [EmailSendingApi.sendEmail](docs/EmailSendingApi.md#sendemail) and [EmailSendingApi.sendSecureEmailOrSecureText](docs/EmailSendingApi.md#sendsecureemailorsecuretext) methods include an optional `attachments` field similar to what is required by the REST API. For the SDK however, you only need to provide a string path that points to the location of the file on local disk you would like to attach.

## Documentation for API Endpoints

All URIs are relative to *https://rest.luxsci.com/perl/api/v2* unless a custom API hostname is specfied. To add custom hostname, provide a `hostname` field to the object provided to `Luxsci.Client`:
```javascript
const secret_key = "SECRET_KEY";
const token = "TOKEN";
const hostname = "example.com";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key,
  hostname //SDK will use https://{hostname}/perl/api/v2
});

```


Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*Luxsci.Client.AuthenticationApi* | [**authentication**](docs/AuthenticationApi.md#authentication) | **POST** /auth | 
*Luxsci.Client.AuthenticationApi* | [**revokeAuthentication**](docs/AuthenticationApi.md#revokeAuthentication) | **DELETE** /auth | 
*Luxsci.Client.ContentLibraryApi* | [**createContentLibraryDirectory**](docs/ContentLibraryApi.md#createContentLibraryDirectory) | **PUT** /user/{username}/content_library/{directory} | 
*Luxsci.Client.ContentLibraryApi* | [**deleteContentLibraryDirectory**](docs/ContentLibraryApi.md#deleteContentLibraryDirectory) | **DELETE** /user/{username}/content_library/{directory} | 
*Luxsci.Client.ContentLibraryApi* | [**deleteContentLibraryFile**](docs/ContentLibraryApi.md#deleteContentLibraryFile) | **DELETE** /user/{username}/content_library/{file_path} | 
*Luxsci.Client.ContentLibraryApi* | [**getContentLibraryDirectory**](docs/ContentLibraryApi.md#getContentLibraryDirectory) | **GET** /user/{username}/content_library/{directory} | 
*Luxsci.Client.ContentLibraryApi* | [**getContentLibraryFile**](docs/ContentLibraryApi.md#getContentLibraryFile) | **GET** /user/{username}/content_library/{file_path} | 
*Luxsci.Client.ContentLibraryApi* | [**uploadContentLibraryFile**](docs/ContentLibraryApi.md#uploadContentLibraryFile) | **PUT** /user/{username}/content_library/{file_path} | 
*Luxsci.Client.DomainsApi* | [**createDomain**](docs/DomainsApi.md#createDomain) | **POST** /account/{accountId}/domains | 
*Luxsci.Client.DomainsApi* | [**deleteDomain**](docs/DomainsApi.md#deleteDomain) | **DELETE** /account/{accountId}/domains/{domainName} | 
*Luxsci.Client.DomainsApi* | [**getDomainDetails**](docs/DomainsApi.md#getDomainDetails) | **GET** /account/{accountId}/domains/{domainName} | 
*Luxsci.Client.DomainsApi* | [**getDomainsReport**](docs/DomainsApi.md#getDomainsReport) | **GET** /account/{accountId}/domains | 
*Luxsci.Client.DomainsApi* | [**updateDomain**](docs/DomainsApi.md#updateDomain) | **PUT** /account/{accountId}/domains/{domainName} | 
*Luxsci.Client.EmailApi* | [**createCustomBounceDomain**](docs/EmailApi.md#createCustomBounceDomain) | **POST** /account/{accountId}/bounce_domain | 
*Luxsci.Client.EmailApi* | [**createDkim**](docs/EmailApi.md#createDkim) | **POST** /account/{accountId}/dkim | 
*Luxsci.Client.EmailApi* | [**deleteDkim**](docs/EmailApi.md#deleteDkim) | **DELETE** /account/{accountId}/dkim/{domainName} | 
*Luxsci.Client.EmailApi* | [**deleteEmailAutoResponder**](docs/EmailApi.md#deleteEmailAutoResponder) | **DELETE** /user/{username}/email/ar/{id} | 
*Luxsci.Client.EmailApi* | [**getDkimDetails**](docs/EmailApi.md#getDkimDetails) | **GET** /account/{accountId}/dkim/{domainName} | 
*Luxsci.Client.EmailApi* | [**getDkimReport**](docs/EmailApi.md#getDkimReport) | **GET** /account/{accountId}/dkim | 
*Luxsci.Client.EmailApi* | [**getEmailAutoResponders**](docs/EmailApi.md#getEmailAutoResponders) | **GET** /user/{username}/email/ar | 
*Luxsci.Client.EmailApi* | [**newEmailAutoResponder**](docs/EmailApi.md#newEmailAutoResponder) | **POST** /user/{username}/email/ar | 
*Luxsci.Client.EmailApi* | [**retrieveSecureLineRecipientListEncryptionData**](docs/EmailApi.md#retrieveSecureLineRecipientListEncryptionData) | **POST** /user/{username}/email/compose/secureline/recipients | 
*Luxsci.Client.EmailApi* | [**updateEmailForwarding**](docs/EmailApi.md#updateEmailForwarding) | **PUT** /user/{username}/email/forwarding | 
*Luxsci.Client.EmailAliasesApi* | [**createAlias**](docs/EmailAliasesApi.md#createAlias) | **POST** /account/{accountId}/aliases | 
*Luxsci.Client.EmailAliasesApi* | [**deleteAlias**](docs/EmailAliasesApi.md#deleteAlias) | **DELETE** /account/{accountId}/aliases/{aliasAddress} | 
*Luxsci.Client.EmailAliasesApi* | [**getAliasDetails**](docs/EmailAliasesApi.md#getAliasDetails) | **GET** /account/{accountId}/aliases/{aliasAddress} | 
*Luxsci.Client.EmailAliasesApi* | [**getAliasesReport**](docs/EmailAliasesApi.md#getAliasesReport) | **GET** /account/{accountId}/aliases | 
*Luxsci.Client.EmailAliasesApi* | [**updateAlias**](docs/EmailAliasesApi.md#updateAlias) | **PUT** /account/{accountId}/aliases/{aliasAddress} | 
*Luxsci.Client.EmailSendingApi* | [**createAccountSuppression**](docs/EmailSendingApi.md#createAccountSuppression) | **PUT** /account/{accountId}/suppression/ | 
*Luxsci.Client.EmailSendingApi* | [**createCustomField**](docs/EmailSendingApi.md#createCustomField) | **PUT** /user/{username}/fields | 
*Luxsci.Client.EmailSendingApi* | [**createEmailContentTag**](docs/EmailSendingApi.md#createEmailContentTag) | **PUT** /user/{username}/content_tags | 
*Luxsci.Client.EmailSendingApi* | [**createEmailTemplate**](docs/EmailSendingApi.md#createEmailTemplate) | **PUT** /user/{username}/templates | 
*Luxsci.Client.EmailSendingApi* | [**createEmailTemplateGroup**](docs/EmailSendingApi.md#createEmailTemplateGroup) | **PUT** /user/{username}/template_group/{template_group_id} | 
*Luxsci.Client.EmailSendingApi* | [**createUserSuppression**](docs/EmailSendingApi.md#createUserSuppression) | **PUT** /user/{username}/suppression/ | 
*Luxsci.Client.EmailSendingApi* | [**deleteAccountSuppression**](docs/EmailSendingApi.md#deleteAccountSuppression) | **DELETE** /account/{accountId}/suppression/{email} | 
*Luxsci.Client.EmailSendingApi* | [**deleteEmailContentTag**](docs/EmailSendingApi.md#deleteEmailContentTag) | **DELETE** /user/{username}/content_tags/{tag_id} | 
*Luxsci.Client.EmailSendingApi* | [**deleteEmailTemplate**](docs/EmailSendingApi.md#deleteEmailTemplate) | **DELETE** /user/{username}/template/{template_id} | 
*Luxsci.Client.EmailSendingApi* | [**deleteEmailTemplateGroup**](docs/EmailSendingApi.md#deleteEmailTemplateGroup) | **DELETE** /user/{username}/template_group/{template_group_id} | 
*Luxsci.Client.EmailSendingApi* | [**deleteUserSuppression**](docs/EmailSendingApi.md#deleteUserSuppression) | **DELETE** /user/{username}/suppression/{email} | 
*Luxsci.Client.EmailSendingApi* | [**getAccountSuppression**](docs/EmailSendingApi.md#getAccountSuppression) | **GET** /account/{accountId}/suppression/{email} | 
*Luxsci.Client.EmailSendingApi* | [**getAccountSuppressionList**](docs/EmailSendingApi.md#getAccountSuppressionList) | **GET** /account/{accountId}/suppression/ | 
*Luxsci.Client.EmailSendingApi* | [**getCustomFields**](docs/EmailSendingApi.md#getCustomFields) | **GET** /user/{username}/fields | 
*Luxsci.Client.EmailSendingApi* | [**getDomainSmtpTlsCapability**](docs/EmailSendingApi.md#getDomainSmtpTlsCapability) | **GET** /user/{username}/email/compose/secureline/tls/{domain} | 
*Luxsci.Client.EmailSendingApi* | [**getEmailContentTag**](docs/EmailSendingApi.md#getEmailContentTag) | **GET** /user/{username}/content_tags/{tag_id} | 
*Luxsci.Client.EmailSendingApi* | [**getEmailContentTagList**](docs/EmailSendingApi.md#getEmailContentTagList) | **GET** /user/{username}/content_tags | 
*Luxsci.Client.EmailSendingApi* | [**getEmailTemplate**](docs/EmailSendingApi.md#getEmailTemplate) | **GET** /user/{username}/template/{template_id} | 
*Luxsci.Client.EmailSendingApi* | [**getEmailTemplateGroups**](docs/EmailSendingApi.md#getEmailTemplateGroups) | **GET** /user/{username}/template_groups | 
*Luxsci.Client.EmailSendingApi* | [**getEmailTemplateList**](docs/EmailSendingApi.md#getEmailTemplateList) | **GET** /user/{username}/templates | 
*Luxsci.Client.EmailSendingApi* | [**getUserSuppression**](docs/EmailSendingApi.md#getUserSuppression) | **GET** /user/{username}/suppression/{email} | 
*Luxsci.Client.EmailSendingApi* | [**getUserSuppressionList**](docs/EmailSendingApi.md#getUserSuppressionList) | **GET** /user/{username}/suppression/ | 
*Luxsci.Client.EmailSendingApi* | [**sendEmail**](docs/EmailSendingApi.md#sendEmail) | **POST** /user/{username}/email/send | 
*Luxsci.Client.EmailSendingApi* | [**sendSecureEmailOrSecureText**](docs/EmailSendingApi.md#sendSecureEmailOrSecureText) | **POST** /user/{username}/email/compose/secureline/send | 
*Luxsci.Client.EmailSendingApi* | [**updateEmailContentTag**](docs/EmailSendingApi.md#updateEmailContentTag) | **POST** /user/{username}/content_tags/{tag_id} | 
*Luxsci.Client.EmailSendingApi* | [**updateEmailTemplate**](docs/EmailSendingApi.md#updateEmailTemplate) | **POST** /user/{username}/template/{template_id} | 
*Luxsci.Client.EmailSendingApi* | [**updateEmailTemplateGroup**](docs/EmailSendingApi.md#updateEmailTemplateGroup) | **POST** /user/{username}/template_group/{template_group_id} | 
*Luxsci.Client.MarketingApi* | [**addMarketingCampaign**](docs/MarketingApi.md#addMarketingCampaign) | **POST** /account/{accountId}/marketing/addCampaign | 
*Luxsci.Client.MarketingApi* | [**addMarketingContact**](docs/MarketingApi.md#addMarketingContact) | **POST** /account/{accountId}/marketing/addContact | 
*Luxsci.Client.MarketingApi* | [**addMarketingContacts**](docs/MarketingApi.md#addMarketingContacts) | **POST** /account/{accountId}/marketing/addContacts | 
*Luxsci.Client.MarketingApi* | [**addMarketingList**](docs/MarketingApi.md#addMarketingList) | **POST** /account/{accountId}/marketing/addList | 
*Luxsci.Client.MarketingApi* | [**addNewMarketingSuppression**](docs/MarketingApi.md#addNewMarketingSuppression) | **POST** /account/{accountId}/marketing/suppress | 
*Luxsci.Client.MarketingApi* | [**deleteMarketingCampaign**](docs/MarketingApi.md#deleteMarketingCampaign) | **DELETE** /account/{accountId}/marketing/deleteCampaign/{id} | 
*Luxsci.Client.MarketingApi* | [**deleteMarketingContactById**](docs/MarketingApi.md#deleteMarketingContactById) | **DELETE** /account/{accountId}/marketing/deleteContact/{id} | 
*Luxsci.Client.MarketingApi* | [**deleteMarketingList**](docs/MarketingApi.md#deleteMarketingList) | **DELETE** /account/{accountId}/marketing/deleteList/{id} | 
*Luxsci.Client.MarketingApi* | [**deleteMarketingListGroup**](docs/MarketingApi.md#deleteMarketingListGroup) | **DELETE** /account/{accountId}/deleteListGroup/{id} | 
*Luxsci.Client.MarketingApi* | [**deleteMarketingSuppression**](docs/MarketingApi.md#deleteMarketingSuppression) | **DELETE** /account/{accountId}/marketing/deleteSuppressed/{type} | 
*Luxsci.Client.MarketingApi* | [**getMarketingCampaignBouncedStatistics**](docs/MarketingApi.md#getMarketingCampaignBouncedStatistics) | **GET** /account/{accountId}/marketing/getCampaignStatsBounced/{schedule_id} | 
*Luxsci.Client.MarketingApi* | [**getMarketingCampaignClickedStatistics**](docs/MarketingApi.md#getMarketingCampaignClickedStatistics) | **GET** /account/{accountId}/marketing/getCampaignStatsClicked/{schedule_id} | 
*Luxsci.Client.MarketingApi* | [**getMarketingCampaignGroups**](docs/MarketingApi.md#getMarketingCampaignGroups) | **GET** /account/{accountId}/marketing/getMarketingCampaignGroups | 
*Luxsci.Client.MarketingApi* | [**getMarketingCampaignOpenedStatistics**](docs/MarketingApi.md#getMarketingCampaignOpenedStatistics) | **GET** /account/{accountId}/marketing/getCampaignStatsOpened/{schedule_id} | 
*Luxsci.Client.MarketingApi* | [**getMarketingCampaignStatisticsSummary**](docs/MarketingApi.md#getMarketingCampaignStatisticsSummary) | **GET** /account/{accountId}/marketing/getCampaignStatsSummary/{schedule_id} | 
*Luxsci.Client.MarketingApi* | [**getMarketingCampaignUnsubscribedStatistics**](docs/MarketingApi.md#getMarketingCampaignUnsubscribedStatistics) | **GET** /account/{accountId}/marketing/getCampaignStatsUnsubscribed/{schedule_id} | 
*Luxsci.Client.MarketingApi* | [**getMarketingCampaigns**](docs/MarketingApi.md#getMarketingCampaigns) | **GET** /account/{accountId}/marketing/getCampaigns | 
*Luxsci.Client.MarketingApi* | [**getMarketingContactById**](docs/MarketingApi.md#getMarketingContactById) | **GET** /account/{accountId}/marketing/getContact/{id} | 
*Luxsci.Client.MarketingApi* | [**getMarketingContacts**](docs/MarketingApi.md#getMarketingContacts) | **GET** /account/{accountId}/marketing/getContacts | 
*Luxsci.Client.MarketingApi* | [**getMarketingListGroups**](docs/MarketingApi.md#getMarketingListGroups) | **GET** /account/{accountId}/marketing/getMarketingListGroups | 
*Luxsci.Client.MarketingApi* | [**getMarketingLists**](docs/MarketingApi.md#getMarketingLists) | **GET** /account/{accountId}/marketing/getLists | 
*Luxsci.Client.MarketingApi* | [**getMarketingScheduledCampaigns**](docs/MarketingApi.md#getMarketingScheduledCampaigns) | **GET** /account/{accountId}/marketing/getMarketingScheduledCampaigns | 
*Luxsci.Client.MarketingApi* | [**getMarketingSuppressions**](docs/MarketingApi.md#getMarketingSuppressions) | **GET** /account/{accountId}/marketing/getSuppressed | 
*Luxsci.Client.MarketingApi* | [**markContactAsUnsubscribed**](docs/MarketingApi.md#markContactAsUnsubscribed) | **PUT** /account/{accountId}/markAsUnsubscribed/{id} | 
*Luxsci.Client.MarketingApi* | [**scheduleMarketingCampaign**](docs/MarketingApi.md#scheduleMarketingCampaign) | **POST** /account/{accountId}/marketing/campaignSchedule | 
*Luxsci.Client.MarketingApi* | [**updateMarketingCampaign**](docs/MarketingApi.md#updateMarketingCampaign) | **PUT** /account/{accountId}/marketing/updateCampaign/{id} | 
*Luxsci.Client.MarketingApi* | [**updateMarketingContactByEmail**](docs/MarketingApi.md#updateMarketingContactByEmail) | **PUT** /account/{accountId}/marketing/updateContact/{email} | 
*Luxsci.Client.MarketingApi* | [**updateMarketingContactById**](docs/MarketingApi.md#updateMarketingContactById) | **PUT** /account/{accountId}/marketing/updateContact/{id} | 
*Luxsci.Client.MarketingApi* | [**updateMarketingList**](docs/MarketingApi.md#updateMarketingList) | **PUT** /account/{accountId}/marketing/updateList/{id} | 
*Luxsci.Client.Marketing3Api* | [**addCampaign**](docs/Marketing3Api.md#addCampaign) | **POST** /user/{username}/marketing/campaigns | 
*Luxsci.Client.Marketing3Api* | [**addContact**](docs/Marketing3Api.md#addContact) | **POST** /user/{username}/marketing/contact | 
*Luxsci.Client.Marketing3Api* | [**addContacts**](docs/Marketing3Api.md#addContacts) | **POST** /user/{username}/marketing/contacts | 
*Luxsci.Client.Marketing3Api* | [**addList**](docs/Marketing3Api.md#addList) | **POST** /user/{username}/marketing/list | 
*Luxsci.Client.Marketing3Api* | [**addListGroup**](docs/Marketing3Api.md#addListGroup) | **PUT** /user/{username}/marketing/list_group/{list_group_id} | 
*Luxsci.Client.Marketing3Api* | [**deleteCampaign**](docs/Marketing3Api.md#deleteCampaign) | **DELETE** /user/{username}/marketing/campaign/{campaign_id} | 
*Luxsci.Client.Marketing3Api* | [**deleteContact**](docs/Marketing3Api.md#deleteContact) | **DELETE** /user/{username}/marketing/contact/{contact_id} | 
*Luxsci.Client.Marketing3Api* | [**deleteList**](docs/Marketing3Api.md#deleteList) | **DELETE** /user/{username}/marketing/list/{list_id} | 
*Luxsci.Client.Marketing3Api* | [**deleteListGroup**](docs/Marketing3Api.md#deleteListGroup) | **DELETE** /user/{username}/marketing/list_group/{list_group_id} | 
*Luxsci.Client.Marketing3Api* | [**getCampaign**](docs/Marketing3Api.md#getCampaign) | **GET** /user/{username}/marketing/campaign/{campaign_id} | 
*Luxsci.Client.Marketing3Api* | [**getCampaigns**](docs/Marketing3Api.md#getCampaigns) | **GET** /user/{username}/marketing/campaigns | 
*Luxsci.Client.Marketing3Api* | [**getContact**](docs/Marketing3Api.md#getContact) | **GET** /user/{username}/marketing/contact/{contact_id} | 
*Luxsci.Client.Marketing3Api* | [**getContacts**](docs/Marketing3Api.md#getContacts) | **GET** /user/{username}/marketing/contacts | 
*Luxsci.Client.Marketing3Api* | [**getList**](docs/Marketing3Api.md#getList) | **GET** /user/{username}/marketing/list/{list_id} | 
*Luxsci.Client.Marketing3Api* | [**getListGroups**](docs/Marketing3Api.md#getListGroups) | **GET** /user/{username}/marketing/list_groups | 
*Luxsci.Client.Marketing3Api* | [**getLists**](docs/Marketing3Api.md#getLists) | **GET** /user/{username}/marketing/lists | 
*Luxsci.Client.Marketing3Api* | [**getReportBounced**](docs/Marketing3Api.md#getReportBounced) | **GET** /user/{username}/marketing/report/bounced | 
*Luxsci.Client.Marketing3Api* | [**getReportClicked**](docs/Marketing3Api.md#getReportClicked) | **GET** /user/{username}/marketing/report/clicked | 
*Luxsci.Client.Marketing3Api* | [**getReportComplaints**](docs/Marketing3Api.md#getReportComplaints) | **GET** /user/{username}/marketing/report/complaints | 
*Luxsci.Client.Marketing3Api* | [**getReportLogs**](docs/Marketing3Api.md#getReportLogs) | **GET** /user/{username}/marketing/report/logs | 
*Luxsci.Client.Marketing3Api* | [**getReportOpened**](docs/Marketing3Api.md#getReportOpened) | **GET** /user/{username}/marketing/report/opened | 
*Luxsci.Client.Marketing3Api* | [**getReportUnsubscribed**](docs/Marketing3Api.md#getReportUnsubscribed) | **GET** /user/{username}/marketing/report/unsubscribed | 
*Luxsci.Client.Marketing3Api* | [**getReportUrls**](docs/Marketing3Api.md#getReportUrls) | **GET** /user/{username}/marketing/report/urls | 
*Luxsci.Client.Marketing3Api* | [**updateCampaign**](docs/Marketing3Api.md#updateCampaign) | **PUT** /user/{username}/marketing/campaign/{campaign_id} | 
*Luxsci.Client.Marketing3Api* | [**updateContact**](docs/Marketing3Api.md#updateContact) | **PUT** /user/{username}/marketing/contact/{contact_id} | 
*Luxsci.Client.Marketing3Api* | [**updateList**](docs/Marketing3Api.md#updateList) | **PUT** /user/{username}/marketing/list/{list_id} | 
*Luxsci.Client.Marketing3Api* | [**updateListGroup**](docs/Marketing3Api.md#updateListGroup) | **POST** /user/{username}/marketing/list_group/{list_group_id} | 
*Luxsci.Client.ReportsApi* | [**getAccountJob**](docs/ReportsApi.md#getAccountJob) | **GET** /account/{accountId}/job/{job_id} | 
*Luxsci.Client.ReportsApi* | [**getAccountJobs**](docs/ReportsApi.md#getAccountJobs) | **GET** /account/{accountId}/jobs | 
*Luxsci.Client.ReportsApi* | [**getAccountSuppressionReport**](docs/ReportsApi.md#getAccountSuppressionReport) | **GET** /account/{accountId}/suppression_v2/ | 
*Luxsci.Client.ReportsApi* | [**getAccountSuppressionSummaryReport**](docs/ReportsApi.md#getAccountSuppressionSummaryReport) | **GET** /account/{accountId}/suppression_count/ | 
*Luxsci.Client.ReportsApi* | [**getEmailFeedBackLoopsReportAccount**](docs/ReportsApi.md#getEmailFeedBackLoopsReportAccount) | **GET** /account/{accountId}/report/email/fbl | 
*Luxsci.Client.ReportsApi* | [**getEmailFeedBackLoopsSummaryReportAccount**](docs/ReportsApi.md#getEmailFeedBackLoopsSummaryReportAccount) | **GET** /account/{accountId}/report/email/fbl_count | 
*Luxsci.Client.ReportsApi* | [**getEmailSMTPClickReportAccount**](docs/ReportsApi.md#getEmailSMTPClickReportAccount) | **GET** /account/{accountId}/report/email/smtp/clicks | 
*Luxsci.Client.ReportsApi* | [**getEmailSMTPClickSummaryReportAccount**](docs/ReportsApi.md#getEmailSMTPClickSummaryReportAccount) | **GET** /account/{accountId}/report/email/smtp/clicks_count | 
*Luxsci.Client.ReportsApi* | [**getEmailSMTPDeliveryStatusReportAccount**](docs/ReportsApi.md#getEmailSMTPDeliveryStatusReportAccount) | **GET** /account/{accountId}/report/email/smtp/delivery | 
*Luxsci.Client.ReportsApi* | [**getEmailSMTPDeliveryStatusSummaryReportAccount**](docs/ReportsApi.md#getEmailSMTPDeliveryStatusSummaryReportAccount) | **GET** /account/{accountId}/report/email/smtp/delivery_count | 
*Luxsci.Client.ReportsApi* | [**getEmailSMTPOpenReportAccount**](docs/ReportsApi.md#getEmailSMTPOpenReportAccount) | **GET** /account/{accountId}/report/email/smtp/opens | 
*Luxsci.Client.ReportsApi* | [**getEmailSMTPOpenSummaryReportAccount**](docs/ReportsApi.md#getEmailSMTPOpenSummaryReportAccount) | **GET** /account/{accountId}/report/email/smtp/opens_count | 
*Luxsci.Client.ReportsApi* | [**getEmailSMTPSentReportAccount**](docs/ReportsApi.md#getEmailSMTPSentReportAccount) | **GET** /account/{accountId}/report/email/smtp/sent | 
*Luxsci.Client.ReportsApi* | [**getEmailSMTPTempFailReportAccount**](docs/ReportsApi.md#getEmailSMTPTempFailReportAccount) | **GET** /account/{accountId}/report/email/smtp/temp_fail | 
*Luxsci.Client.ReportsApi* | [**getEmailWebMailClickReportAccount**](docs/ReportsApi.md#getEmailWebMailClickReportAccount) | **GET** /account/{accountId}/report/email/webmail/clicks | 
*Luxsci.Client.ReportsApi* | [**getEmailWebMailDeliveryStatusReportAccount**](docs/ReportsApi.md#getEmailWebMailDeliveryStatusReportAccount) | **GET** /account/{accountId}/report/email/webmail/delivery | 
*Luxsci.Client.ReportsApi* | [**getEmailWebMailOpenReportAccount**](docs/ReportsApi.md#getEmailWebMailOpenReportAccount) | **GET** /account/{accountId}/report/email/webmail/opens | 
*Luxsci.Client.ReportsApi* | [**getEmailWebMailSentReportAccount**](docs/ReportsApi.md#getEmailWebMailSentReportAccount) | **GET** /account/{accountId}/report/email/webmail/sent | 
*Luxsci.Client.ReportsApi* | [**getSMTPLoginFailureReportAccount**](docs/ReportsApi.md#getSMTPLoginFailureReportAccount) | **GET** /account/{accountId}/report/login_fail/smtp | 
*Luxsci.Client.SecureFormApi* | [**deleteSecureFormDatabaseFile**](docs/SecureFormApi.md#deleteSecureFormDatabaseFile) | **DELETE** /account/{accountId}/secureforms/{formID}/db/{rowIndex}/file/{fileIndex} | 
*Luxsci.Client.SecureFormApi* | [**deleteSecureFormDatabaseRow**](docs/SecureFormApi.md#deleteSecureFormDatabaseRow) | **DELETE** /account/{accountId}/secureforms/{formID}/db/rows/{index} | 
*Luxsci.Client.SecureFormApi* | [**getSecureForm**](docs/SecureFormApi.md#getSecureForm) | **GET** /account/{accountId}/secureforms/{formID} | 
*Luxsci.Client.SecureFormApi* | [**getSecureFormDatabaseFile**](docs/SecureFormApi.md#getSecureFormDatabaseFile) | **GET** /account/{accountId}/secureforms/{formID}/db/{rowIndex}/file/{fileIndex} | 
*Luxsci.Client.SecureFormApi* | [**getSecureFormDatabasePosts**](docs/SecureFormApi.md#getSecureFormDatabasePosts) | **GET** /account/{accountId}/secureforms/{formID}/db | 
*Luxsci.Client.SecureFormApi* | [**getSecureFormDatabaseRow**](docs/SecureFormApi.md#getSecureFormDatabaseRow) | **GET** /account/{accountId}/secureforms/{formID}/db/rows/{index} | 
*Luxsci.Client.SecureFormApi* | [**getSecureFormDatabaseRows**](docs/SecureFormApi.md#getSecureFormDatabaseRows) | **GET** /account/{accountId}/secureforms/{formID}/db/rows | 
*Luxsci.Client.SecureFormApi* | [**getSecureFormList**](docs/SecureFormApi.md#getSecureFormList) | **GET** /account/{accountId}/secureforms | 
*Luxsci.Client.SecureSendApi* | [**changeSecureSendUserPassword**](docs/SecureSendApi.md#changeSecureSendUserPassword) | **PUT** /account/{accountId}/pl/namespaces/{namespaceId}/users/{username}/password | 
*Luxsci.Client.SecureSendApi* | [**createOrUpdateSecureSendUser**](docs/SecureSendApi.md#createOrUpdateSecureSendUser) | **PUT** /account/{accountId}/pl/namespaces/{namespaceId}/users/{username} | 
*Luxsci.Client.SecureSendApi* | [**getSecureSendUserList**](docs/SecureSendApi.md#getSecureSendUserList) | **GET** /account/{accountId}/pl/namespaces/{namespaceId}/users | 
*Luxsci.Client.SecureSendApi* | [**getSecureSendUserSingleSignOnLink**](docs/SecureSendApi.md#getSecureSendUserSingleSignOnLink) | **GET** /account/{accountId}/pl/namespaces/{namespaceId}/users/{username}/password | 
*Luxsci.Client.ServersApi* | [**getServerStatus**](docs/ServersApi.md#getServerStatus) | **GET** /account/{accountId}/server/{serverId} | 
*Luxsci.Client.ServersApi* | [**getServers**](docs/ServersApi.md#getServers) | **GET** /account/{accountId}/servers | 
*Luxsci.Client.ServersApi* | [**serverEmptyAllEmailQueues**](docs/ServersApi.md#serverEmptyAllEmailQueues) | **DELETE** /account/{accountId}/server/{serverId}/sending_queues/all | 
*Luxsci.Client.ServersApi* | [**serverEmptyEmailQueues**](docs/ServersApi.md#serverEmptyEmailQueues) | **DELETE** /account/{accountId}/server/{serverId}/sending_queues | 
*Luxsci.Client.ServersApi* | [**setServerSendngRate**](docs/ServersApi.md#setServerSendngRate) | **POST** /account/{accountId}/server/{serverId}/sending_rate | 
*Luxsci.Client.UserReportsApi* | [**getEmailFeedBackLoopsReportUser**](docs/UserReportsApi.md#getEmailFeedBackLoopsReportUser) | **GET** /user/{username}/report/email/fbl | 
*Luxsci.Client.UserReportsApi* | [**getEmailFeedBackLoopsSummaryReportUser**](docs/UserReportsApi.md#getEmailFeedBackLoopsSummaryReportUser) | **GET** /user/{username}/report/email/fbl_count | 
*Luxsci.Client.UserReportsApi* | [**getEmailSMTPClickReportUser**](docs/UserReportsApi.md#getEmailSMTPClickReportUser) | **GET** /user/{username}/report/email/smtp/clicks | 
*Luxsci.Client.UserReportsApi* | [**getEmailSMTPClickSummaryReportUser**](docs/UserReportsApi.md#getEmailSMTPClickSummaryReportUser) | **GET** /user/{username}/report/email/smtp/clicks_count | 
*Luxsci.Client.UserReportsApi* | [**getEmailSMTPDeliveryStatusReportUser**](docs/UserReportsApi.md#getEmailSMTPDeliveryStatusReportUser) | **GET** /user/{username}/report/email/smtp/delivery | 
*Luxsci.Client.UserReportsApi* | [**getEmailSMTPDeliveryStatusSummaryReportUser**](docs/UserReportsApi.md#getEmailSMTPDeliveryStatusSummaryReportUser) | **GET** /user/{username}/report/email/smtp/delivery_count | 
*Luxsci.Client.UserReportsApi* | [**getEmailSMTPLoginFailureReportUser**](docs/UserReportsApi.md#getEmailSMTPLoginFailureReportUser) | **GET** /user/{username}/report/login_fail/smtp | 
*Luxsci.Client.UserReportsApi* | [**getEmailSMTPOpenReportUser**](docs/UserReportsApi.md#getEmailSMTPOpenReportUser) | **GET** /user/{username}/report/email/smtp/opens | 
*Luxsci.Client.UserReportsApi* | [**getEmailSMTPOpenSummaryReportUser**](docs/UserReportsApi.md#getEmailSMTPOpenSummaryReportUser) | **GET** /user/{username}/report/email/smtp/opens_count | 
*Luxsci.Client.UserReportsApi* | [**getEmailSMTPSentReportUser**](docs/UserReportsApi.md#getEmailSMTPSentReportUser) | **GET** /user/{username}/report/email/smtp/sent | 
*Luxsci.Client.UserReportsApi* | [**getEmailSMTPTempFailReportUser**](docs/UserReportsApi.md#getEmailSMTPTempFailReportUser) | **GET** /user/{username}/report/email/smtp/temp_fail | 
*Luxsci.Client.UserReportsApi* | [**getEmailWebMailClickReportUser**](docs/UserReportsApi.md#getEmailWebMailClickReportUser) | **GET** /user/{username}/report/email/webmail/clicks | 
*Luxsci.Client.UserReportsApi* | [**getEmailWebMailDeliveryStatusReportUser**](docs/UserReportsApi.md#getEmailWebMailDeliveryStatusReportUser) | **GET** /user/{username}/report/email/webmail/delivery | 
*Luxsci.Client.UserReportsApi* | [**getEmailWebMailOpenReportUser**](docs/UserReportsApi.md#getEmailWebMailOpenReportUser) | **GET** /user/{username}/report/email/webmail/opens | 
*Luxsci.Client.UserReportsApi* | [**getEmailWebMailSentReportUser**](docs/UserReportsApi.md#getEmailWebMailSentReportUser) | **GET** /user/{username}/report/email/webmail/sent | 
*Luxsci.Client.UserReportsApi* | [**getUserJob**](docs/UserReportsApi.md#getUserJob) | **GET** /user/{username}/job/{job_id} | 
*Luxsci.Client.UserReportsApi* | [**getUserJobs**](docs/UserReportsApi.md#getUserJobs) | **GET** /user/{username}/jobs | 
*Luxsci.Client.UserReportsApi* | [**getUserSuppressionReport**](docs/UserReportsApi.md#getUserSuppressionReport) | **GET** /user/{username}/suppression_v2/ | 
*Luxsci.Client.UserReportsApi* | [**getUserSuppressionSummaryReport**](docs/UserReportsApi.md#getUserSuppressionSummaryReport) | **GET** /user/{username}/suppression_count/ | 
*Luxsci.Client.UsersApi* | [**changeUserPassword**](docs/UsersApi.md#changeUserPassword) | **PUT** /user/{username}/password | 
*Luxsci.Client.UsersApi* | [**createAppSpecificPassword**](docs/UsersApi.md#createAppSpecificPassword) | **POST** /user/{username}/app-password/{suffix} | 
*Luxsci.Client.UsersApi* | [**createUser**](docs/UsersApi.md#createUser) | **POST** /account/{accountId}/users | 
*Luxsci.Client.UsersApi* | [**deleteAppSpecificPassword**](docs/UsersApi.md#deleteAppSpecificPassword) | **DELETE** /user/{username}/app-password/{suffix} | 
*Luxsci.Client.UsersApi* | [**deleteUser**](docs/UsersApi.md#deleteUser) | **DELETE** /account/{accountId}/users/{username} | 
*Luxsci.Client.UsersApi* | [**getTimeZonesList**](docs/UsersApi.md#getTimeZonesList) | **GET** /user/{username}/settings/timezones | 
*Luxsci.Client.UsersApi* | [**getUser**](docs/UsersApi.md#getUser) | **GET** /user/{username} | 
*Luxsci.Client.UsersApi* | [**getUserBrandingInformation**](docs/UsersApi.md#getUserBrandingInformation) | **GET** /user/{username}/branding | 
*Luxsci.Client.UsersApi* | [**getUserProfile**](docs/UsersApi.md#getUserProfile) | **GET** /user/{username}/profile | 
*Luxsci.Client.UsersApi* | [**getUserReport**](docs/UsersApi.md#getUserReport) | **GET** /account/{accountId}/users | 
*Luxsci.Client.UsersApi* | [**getUserReport2**](docs/UsersApi.md#getUserReport2) | **GET** /account/{accountId}/users/report | 
*Luxsci.Client.UsersApi* | [**getUserSettings**](docs/UsersApi.md#getUserSettings) | **GET** /user/{username}/settings | 
*Luxsci.Client.UsersApi* | [**getUserSingleSignOnLoginURL**](docs/UsersApi.md#getUserSingleSignOnLoginURL) | **GET** /user/{username}/password | 
*Luxsci.Client.UsersApi* | [**getUserSummaryReport**](docs/UsersApi.md#getUserSummaryReport) | **GET** /account/{accountId}/users/report_count | 
*Luxsci.Client.UsersApi* | [**listAllAppSpecificPassword**](docs/UsersApi.md#listAllAppSpecificPassword) | **GET** /user/{username}/app-password | 
*Luxsci.Client.UsersApi* | [**listAppSpecificPasswords**](docs/UsersApi.md#listAppSpecificPasswords) | **GET** /user/{username}/app-password/{suffix} | 
*Luxsci.Client.UsersApi* | [**renameUser**](docs/UsersApi.md#renameUser) | **POST** /account/{accountId}/users/{username}/rename | 
*Luxsci.Client.UsersApi* | [**updateUser**](docs/UsersApi.md#updateUser) | **PUT** /user/{username} | 
*Luxsci.Client.UsersApi* | [**updateUserProfile**](docs/UsersApi.md#updateUserProfile) | **PUT** /user/{username}/profile | 
*Luxsci.Client.UsersApi* | [**updateUserSettings**](docs/UsersApi.md#updateUserSettings) | **PUT** /account/{accountId}/users/{username} | 
*Luxsci.Client.WebAidesApi* | [**addUpdateWebAideEntries**](docs/WebAidesApi.md#addUpdateWebAideEntries) | **POST** /user/{username}/webaides/{webaide_type}/{webaide_id}/entries/import | 
*Luxsci.Client.WebAidesApi* | [**deleteWebAide**](docs/WebAidesApi.md#deleteWebAide) | **DELETE** /user/{username}/webaides/{webaide_type}/{webaide_id} | 
*Luxsci.Client.WebAidesApi* | [**deleteWebAideEntries**](docs/WebAidesApi.md#deleteWebAideEntries) | **POST** /user/{username}/webaides/{webaide_type}/{webaide_id}/entries/delete | 
*Luxsci.Client.WebAidesApi* | [**deleteWebAideEntry**](docs/WebAidesApi.md#deleteWebAideEntry) | **DELETE** /user/{username}/webaides/{webaide_type}/{webaide_id}/{entry_id} | 
*Luxsci.Client.WebAidesApi* | [**getCalendarEntriesDateRange**](docs/WebAidesApi.md#getCalendarEntriesDateRange) | **GET** /user/{username}/webaides/calendar/{webaide_id}/entries/date_range | 
*Luxsci.Client.WebAidesApi* | [**getWebAide**](docs/WebAidesApi.md#getWebAide) | **GET** /user/{username}/webaides/{webaide_type}/{webaide_id} | 
*Luxsci.Client.WebAidesApi* | [**getWebAideChanges**](docs/WebAidesApi.md#getWebAideChanges) | **GET** /user/{username}/webaides/{webaide_type}/{webaide_id}/entries/changes | 
*Luxsci.Client.WebAidesApi* | [**getWebAideEntries**](docs/WebAidesApi.md#getWebAideEntries) | **GET** /user/{username}/webaides/{webaide_type}/{webaide_id}/entries | 
*Luxsci.Client.WebAidesApi* | [**getWebAideEntry**](docs/WebAidesApi.md#getWebAideEntry) | **GET** /user/{username}/webaides/{webaide_type}/{webaide_id}/{entry_id} | 
*Luxsci.Client.WebAidesApi* | [**getWebAides**](docs/WebAidesApi.md#getWebAides) | **GET** /user/{username}/webaides/{webaide_type} | 
*Luxsci.Client.WebAidesApi* | [**newWebAide**](docs/WebAidesApi.md#newWebAide) | **POST** /user/{username}/webaides/{webaide_type} | 
*Luxsci.Client.WebAidesApi* | [**newWebAideEntry**](docs/WebAidesApi.md#newWebAideEntry) | **POST** /user/{username}/webaides/{webaide_type}/{webaide_id} | 
*Luxsci.Client.WebAidesApi* | [**updateWebAideEntry**](docs/WebAidesApi.md#updateWebAideEntry) | **PUT** /user/{username}/webaides/{webaide_type}/{webaide_id}/{entry_id} | 

## Documentation for Models

 - [Luxsci.AccountIdAliasesBody](docs/AccountIdAliasesBody.md)
 - [Luxsci.AccountIdBounceDomainBody](docs/AccountIdBounceDomainBody.md)
 - [Luxsci.AccountIdDkimBody](docs/AccountIdDkimBody.md)
 - [Luxsci.AccountIdDomainsBody](docs/AccountIdDomainsBody.md)
 - [Luxsci.AccountIdUsersBody](docs/AccountIdUsersBody.md)
 - [Luxsci.AccountaccountIdaliasesAliases](docs/AccountaccountIdaliasesAliases.md)
 - [Luxsci.Alias](docs/Alias.md)
 - [Luxsci.AliasesAliasAddressBody](docs/AliasesAliasAddressBody.md)
 - [Luxsci.AllOfinlineResponse20075Data](docs/AllOfinlineResponse20075Data.md)
 - [Luxsci.AnyOfinlineResponse20070DataRow](docs/AnyOfinlineResponse20070DataRow.md)
 - [Luxsci.ApppasswordSuffixBody](docs/ApppasswordSuffixBody.md)
 - [Luxsci.AuthBody](docs/AuthBody.md)
 - [Luxsci.Campaign](docs/Campaign.md)
 - [Luxsci.Contact](docs/Contact.md)
 - [Luxsci.ContentLibraryFilePathBody](docs/ContentLibraryFilePathBody.md)
 - [Luxsci.ContentLibraryMeta](docs/ContentLibraryMeta.md)
 - [Luxsci.ContentTag](docs/ContentTag.md)
 - [Luxsci.DkimReport](docs/DkimReport.md)
 - [Luxsci.DomainReport](docs/DomainReport.md)
 - [Luxsci.DomainsDomainNameBody](docs/DomainsDomainNameBody.md)
 - [Luxsci.EmailArBody](docs/EmailArBody.md)
 - [Luxsci.EmailForwardingBody](docs/EmailForwardingBody.md)
 - [Luxsci.EmailSendBody](docs/EmailSendBody.md)
 - [Luxsci.EmailSendBody1](docs/EmailSendBody1.md)
 - [Luxsci.EntriesDeleteBody](docs/EntriesDeleteBody.md)
 - [Luxsci.EntriesImportBody](docs/EntriesImportBody.md)
 - [Luxsci.InlineResponse200](docs/InlineResponse200.md)
 - [Luxsci.InlineResponse2001](docs/InlineResponse2001.md)
 - [Luxsci.InlineResponse20010](docs/InlineResponse20010.md)
 - [Luxsci.InlineResponse20010Data](docs/InlineResponse20010Data.md)
 - [Luxsci.InlineResponse20011](docs/InlineResponse20011.md)
 - [Luxsci.InlineResponse20011Data](docs/InlineResponse20011Data.md)
 - [Luxsci.InlineResponse20012](docs/InlineResponse20012.md)
 - [Luxsci.InlineResponse20013](docs/InlineResponse20013.md)
 - [Luxsci.InlineResponse20013Data](docs/InlineResponse20013Data.md)
 - [Luxsci.InlineResponse20014](docs/InlineResponse20014.md)
 - [Luxsci.InlineResponse20014Data](docs/InlineResponse20014Data.md)
 - [Luxsci.InlineResponse20015](docs/InlineResponse20015.md)
 - [Luxsci.InlineResponse20015Data](docs/InlineResponse20015Data.md)
 - [Luxsci.InlineResponse20016](docs/InlineResponse20016.md)
 - [Luxsci.InlineResponse20016Data](docs/InlineResponse20016Data.md)
 - [Luxsci.InlineResponse20017](docs/InlineResponse20017.md)
 - [Luxsci.InlineResponse20017Data](docs/InlineResponse20017Data.md)
 - [Luxsci.InlineResponse20018](docs/InlineResponse20018.md)
 - [Luxsci.InlineResponse20018Data](docs/InlineResponse20018Data.md)
 - [Luxsci.InlineResponse20019](docs/InlineResponse20019.md)
 - [Luxsci.InlineResponse20019Data](docs/InlineResponse20019Data.md)
 - [Luxsci.InlineResponse2001Data](docs/InlineResponse2001Data.md)
 - [Luxsci.InlineResponse2002](docs/InlineResponse2002.md)
 - [Luxsci.InlineResponse20020](docs/InlineResponse20020.md)
 - [Luxsci.InlineResponse20020Data](docs/InlineResponse20020Data.md)
 - [Luxsci.InlineResponse20021](docs/InlineResponse20021.md)
 - [Luxsci.InlineResponse20022](docs/InlineResponse20022.md)
 - [Luxsci.InlineResponse20023](docs/InlineResponse20023.md)
 - [Luxsci.InlineResponse20023Data](docs/InlineResponse20023Data.md)
 - [Luxsci.InlineResponse20024](docs/InlineResponse20024.md)
 - [Luxsci.InlineResponse20024Data](docs/InlineResponse20024Data.md)
 - [Luxsci.InlineResponse20025](docs/InlineResponse20025.md)
 - [Luxsci.InlineResponse20025Data](docs/InlineResponse20025Data.md)
 - [Luxsci.InlineResponse20026](docs/InlineResponse20026.md)
 - [Luxsci.InlineResponse20026Data](docs/InlineResponse20026Data.md)
 - [Luxsci.InlineResponse20027](docs/InlineResponse20027.md)
 - [Luxsci.InlineResponse20027Data](docs/InlineResponse20027Data.md)
 - [Luxsci.InlineResponse20028](docs/InlineResponse20028.md)
 - [Luxsci.InlineResponse20028Data](docs/InlineResponse20028Data.md)
 - [Luxsci.InlineResponse20029](docs/InlineResponse20029.md)
 - [Luxsci.InlineResponse20029Data](docs/InlineResponse20029Data.md)
 - [Luxsci.InlineResponse2002Data](docs/InlineResponse2002Data.md)
 - [Luxsci.InlineResponse2003](docs/InlineResponse2003.md)
 - [Luxsci.InlineResponse20030](docs/InlineResponse20030.md)
 - [Luxsci.InlineResponse20030Data](docs/InlineResponse20030Data.md)
 - [Luxsci.InlineResponse20031](docs/InlineResponse20031.md)
 - [Luxsci.InlineResponse20031Data](docs/InlineResponse20031Data.md)
 - [Luxsci.InlineResponse20032](docs/InlineResponse20032.md)
 - [Luxsci.InlineResponse20032Data](docs/InlineResponse20032Data.md)
 - [Luxsci.InlineResponse20033](docs/InlineResponse20033.md)
 - [Luxsci.InlineResponse20034](docs/InlineResponse20034.md)
 - [Luxsci.InlineResponse20035](docs/InlineResponse20035.md)
 - [Luxsci.InlineResponse20035Data](docs/InlineResponse20035Data.md)
 - [Luxsci.InlineResponse20036](docs/InlineResponse20036.md)
 - [Luxsci.InlineResponse20037](docs/InlineResponse20037.md)
 - [Luxsci.InlineResponse20037Data](docs/InlineResponse20037Data.md)
 - [Luxsci.InlineResponse20038](docs/InlineResponse20038.md)
 - [Luxsci.InlineResponse20038Data](docs/InlineResponse20038Data.md)
 - [Luxsci.InlineResponse20039](docs/InlineResponse20039.md)
 - [Luxsci.InlineResponse20039Data](docs/InlineResponse20039Data.md)
 - [Luxsci.InlineResponse20039DataContacts](docs/InlineResponse20039DataContacts.md)
 - [Luxsci.InlineResponse2004](docs/InlineResponse2004.md)
 - [Luxsci.InlineResponse20040](docs/InlineResponse20040.md)
 - [Luxsci.InlineResponse20040Data](docs/InlineResponse20040Data.md)
 - [Luxsci.InlineResponse20041](docs/InlineResponse20041.md)
 - [Luxsci.InlineResponse20042](docs/InlineResponse20042.md)
 - [Luxsci.InlineResponse20042Data](docs/InlineResponse20042Data.md)
 - [Luxsci.InlineResponse20043](docs/InlineResponse20043.md)
 - [Luxsci.InlineResponse20044](docs/InlineResponse20044.md)
 - [Luxsci.InlineResponse20044Data](docs/InlineResponse20044Data.md)
 - [Luxsci.InlineResponse20045](docs/InlineResponse20045.md)
 - [Luxsci.InlineResponse20045Data](docs/InlineResponse20045Data.md)
 - [Luxsci.InlineResponse20046](docs/InlineResponse20046.md)
 - [Luxsci.InlineResponse20047](docs/InlineResponse20047.md)
 - [Luxsci.InlineResponse20048](docs/InlineResponse20048.md)
 - [Luxsci.InlineResponse20048Data](docs/InlineResponse20048Data.md)
 - [Luxsci.InlineResponse20049](docs/InlineResponse20049.md)
 - [Luxsci.InlineResponse2004Data](docs/InlineResponse2004Data.md)
 - [Luxsci.InlineResponse2005](docs/InlineResponse2005.md)
 - [Luxsci.InlineResponse20050](docs/InlineResponse20050.md)
 - [Luxsci.InlineResponse20051](docs/InlineResponse20051.md)
 - [Luxsci.InlineResponse20052](docs/InlineResponse20052.md)
 - [Luxsci.InlineResponse20053](docs/InlineResponse20053.md)
 - [Luxsci.InlineResponse20053Data](docs/InlineResponse20053Data.md)
 - [Luxsci.InlineResponse20054](docs/InlineResponse20054.md)
 - [Luxsci.InlineResponse20054Data](docs/InlineResponse20054Data.md)
 - [Luxsci.InlineResponse20055](docs/InlineResponse20055.md)
 - [Luxsci.InlineResponse20056](docs/InlineResponse20056.md)
 - [Luxsci.InlineResponse20056Data](docs/InlineResponse20056Data.md)
 - [Luxsci.InlineResponse20057](docs/InlineResponse20057.md)
 - [Luxsci.InlineResponse20057Data](docs/InlineResponse20057Data.md)
 - [Luxsci.InlineResponse20058](docs/InlineResponse20058.md)
 - [Luxsci.InlineResponse20059](docs/InlineResponse20059.md)
 - [Luxsci.InlineResponse20059Data](docs/InlineResponse20059Data.md)
 - [Luxsci.InlineResponse2006](docs/InlineResponse2006.md)
 - [Luxsci.InlineResponse20060](docs/InlineResponse20060.md)
 - [Luxsci.InlineResponse20061](docs/InlineResponse20061.md)
 - [Luxsci.InlineResponse20062](docs/InlineResponse20062.md)
 - [Luxsci.InlineResponse20063](docs/InlineResponse20063.md)
 - [Luxsci.InlineResponse20064](docs/InlineResponse20064.md)
 - [Luxsci.InlineResponse20064Data](docs/InlineResponse20064Data.md)
 - [Luxsci.InlineResponse20065](docs/InlineResponse20065.md)
 - [Luxsci.InlineResponse20066](docs/InlineResponse20066.md)
 - [Luxsci.InlineResponse20067](docs/InlineResponse20067.md)
 - [Luxsci.InlineResponse20068](docs/InlineResponse20068.md)
 - [Luxsci.InlineResponse20068Data](docs/InlineResponse20068Data.md)
 - [Luxsci.InlineResponse20069](docs/InlineResponse20069.md)
 - [Luxsci.InlineResponse20069Data](docs/InlineResponse20069Data.md)
 - [Luxsci.InlineResponse2006Data](docs/InlineResponse2006Data.md)
 - [Luxsci.InlineResponse2007](docs/InlineResponse2007.md)
 - [Luxsci.InlineResponse20070](docs/InlineResponse20070.md)
 - [Luxsci.InlineResponse20070Data](docs/InlineResponse20070Data.md)
 - [Luxsci.InlineResponse20071](docs/InlineResponse20071.md)
 - [Luxsci.InlineResponse20071Data](docs/InlineResponse20071Data.md)
 - [Luxsci.InlineResponse20072](docs/InlineResponse20072.md)
 - [Luxsci.InlineResponse20072Data](docs/InlineResponse20072Data.md)
 - [Luxsci.InlineResponse20073](docs/InlineResponse20073.md)
 - [Luxsci.InlineResponse20073Data](docs/InlineResponse20073Data.md)
 - [Luxsci.InlineResponse20074](docs/InlineResponse20074.md)
 - [Luxsci.InlineResponse20075](docs/InlineResponse20075.md)
 - [Luxsci.InlineResponse2007Data](docs/InlineResponse2007Data.md)
 - [Luxsci.InlineResponse2008](docs/InlineResponse2008.md)
 - [Luxsci.InlineResponse2008Data](docs/InlineResponse2008Data.md)
 - [Luxsci.InlineResponse2009](docs/InlineResponse2009.md)
 - [Luxsci.InlineResponse2009Data](docs/InlineResponse2009Data.md)
 - [Luxsci.InlineResponse201](docs/InlineResponse201.md)
 - [Luxsci.InlineResponse2011](docs/InlineResponse2011.md)
 - [Luxsci.InlineResponse2011Data](docs/InlineResponse2011Data.md)
 - [Luxsci.ListGroupListGroupIdBody](docs/ListGroupListGroupIdBody.md)
 - [Luxsci.ListGroupListGroupIdBody1](docs/ListGroupListGroupIdBody1.md)
 - [Luxsci.MarketingAddCampaignBody](docs/MarketingAddCampaignBody.md)
 - [Luxsci.MarketingAddContactBody](docs/MarketingAddContactBody.md)
 - [Luxsci.MarketingAddContactsBody](docs/MarketingAddContactsBody.md)
 - [Luxsci.MarketingAddListBody](docs/MarketingAddListBody.md)
 - [Luxsci.MarketingCampaignScheduleBody](docs/MarketingCampaignScheduleBody.md)
 - [Luxsci.MarketingSuppressBody](docs/MarketingSuppressBody.md)
 - [Luxsci.Message](docs/Message.md)
 - [Luxsci.OneOfReportResponseRowsItems](docs/OneOfReportResponseRowsItems.md)
 - [Luxsci.ReportResponse](docs/ReportResponse.md)
 - [Luxsci.SM3CSVResponse](docs/SM3CSVResponse.md)
 - [Luxsci.SM3Campaign](docs/SM3Campaign.md)
 - [Luxsci.SM3CampaignPOSTBody](docs/SM3CampaignPOSTBody.md)
 - [Luxsci.SM3CampaignPUTBody](docs/SM3CampaignPUTBody.md)
 - [Luxsci.SM3Contact](docs/SM3Contact.md)
 - [Luxsci.SM3ContactPOSTBody](docs/SM3ContactPOSTBody.md)
 - [Luxsci.SM3ContactPOSTBodyDerived](docs/SM3ContactPOSTBodyDerived.md)
 - [Luxsci.SM3ContactPUTBody](docs/SM3ContactPUTBody.md)
 - [Luxsci.SM3CustomField](docs/SM3CustomField.md)
 - [Luxsci.SM3List](docs/SM3List.md)
 - [Luxsci.SM3ListBase](docs/SM3ListBase.md)
 - [Luxsci.SM3ListBody](docs/SM3ListBody.md)
 - [Luxsci.SecureForm](docs/SecureForm.md)
 - [Luxsci.SecureFormDbRow](docs/SecureFormDbRow.md)
 - [Luxsci.SecureFormDbRowFiles_](docs/SecureFormDbRowFiles_.md)
 - [Luxsci.SecurelineRecipientsBody](docs/SecurelineRecipientsBody.md)
 - [Luxsci.SecurelineSendBody](docs/SecurelineSendBody.md)
 - [Luxsci.Server](docs/Server.md)
 - [Luxsci.ServerIdSendingRateBody](docs/ServerIdSendingRateBody.md)
 - [Luxsci.StringOrNumber](docs/StringOrNumber.md)
 - [Luxsci.Suppression](docs/Suppression.md)
 - [Luxsci.Template](docs/Template.md)
 - [Luxsci.TemplateGroupTemplateGroupIdBody](docs/TemplateGroupTemplateGroupIdBody.md)
 - [Luxsci.TemplateGroupTemplateGroupIdBody1](docs/TemplateGroupTemplateGroupIdBody1.md)
 - [Luxsci.UpdateCampaignIdBody](docs/UpdateCampaignIdBody.md)
 - [Luxsci.UpdateContactEmailBody](docs/UpdateContactEmailBody.md)
 - [Luxsci.UpdateContactRequestBody](docs/UpdateContactRequestBody.md)
 - [Luxsci.UpdateListIdBody](docs/UpdateListIdBody.md)
 - [Luxsci.UserUsernameBody](docs/UserUsernameBody.md)
 - [Luxsci.UsernameFieldsBody](docs/UsernameFieldsBody.md)
 - [Luxsci.UsernamePasswordBody](docs/UsernamePasswordBody.md)
 - [Luxsci.UsernamePasswordBody1](docs/UsernamePasswordBody1.md)
 - [Luxsci.UsernameProfileBody](docs/UsernameProfileBody.md)
 - [Luxsci.UsernameRenameBody](docs/UsernameRenameBody.md)
 - [Luxsci.UsersUsernameBody](docs/UsersUsernameBody.md)
 - [Luxsci.UsersUsernameBody1](docs/UsersUsernameBody1.md)
 - [Luxsci.UserusernameemailsendJson](docs/UserusernameemailsendJson.md)
 - [Luxsci.UserusernameemailsendJsonMessage](docs/UserusernameemailsendJsonMessage.md)
 - [Luxsci.UserusernameemailsendJsonMessages](docs/UserusernameemailsendJsonMessages.md)
 - [Luxsci.WebAide](docs/WebAide.md)
 - [Luxsci.WebaideIdEntryIdBody](docs/WebaideIdEntryIdBody.md)
 - [Luxsci.WebaideTypeWebaideIdBody](docs/WebaideTypeWebaideIdBody.md)
 - [Luxsci.WebaidesWebaideTypeBody](docs/WebaidesWebaideTypeBody.md)

