# Luxsci.ContentLibraryApi

All URIs are relative to *https://rest.luxsci.com/perl/api/v2*, unless a hostname is provided ([see README](../README.md#documentation-for-api-endpoints))

Method | HTTP request | Description
------------- | ------------- | -------------
[**createContentLibraryDirectory**](ContentLibraryApi.md#createContentLibraryDirectory) | **PUT** /user/{username}/content_library/{directory} | 
[**deleteContentLibraryDirectory**](ContentLibraryApi.md#deleteContentLibraryDirectory) | **DELETE** /user/{username}/content_library/{directory} | 
[**deleteContentLibraryFile**](ContentLibraryApi.md#deleteContentLibraryFile) | **DELETE** /user/{username}/content_library/{file_path} | 
[**getContentLibraryDirectory**](ContentLibraryApi.md#getContentLibraryDirectory) | **GET** /user/{username}/content_library/{directory} | 
[**getContentLibraryFile**](ContentLibraryApi.md#getContentLibraryFile) | **GET** /user/{username}/content_library/{file_path} | 
[**uploadContentLibraryFile**](ContentLibraryApi.md#uploadContentLibraryFile) | **PUT** /user/{username}/content_library/{file_path} | 

<a name="createContentLibraryDirectory"></a>
# **createContentLibraryDirectory**
> InlineResponse201 createContentLibraryDirectory(username, directory, opts)



Create a new Content Library directory.  {{ACL: User Email: Content Library}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.ContentLibraryApi

let username = "username_example"; // String | 
let directory = "directory_example"; // String | Starting with the / following /content_library, this is the directory in {username} to create. This directory must not exist and, if it is a subdirectory, the parent directories must all exist.
let opts = { 
};
apiInstance.createContentLibraryDirectory(username, directory, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **directory** | **String**| Starting with the / following /content_library, this is the directory in {username} to create. This directory must not exist and, if it is a subdirectory, the parent directories must all exist. | 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="deleteContentLibraryDirectory"></a>
# **deleteContentLibraryDirectory**
> InlineResponse201 deleteContentLibraryDirectory(username, directory, opts)



Delete an empty Content Library directory.  {{ACL: User Email: Content Library}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.ContentLibraryApi

let username = "username_example"; // String | 
let directory = "directory_example"; // String | Starting with the / following /content_library, this is the directory in {username} to create. This directory must not exist and, if it is a subdirectory, the parent directories must all exist.
let opts = { 
};
apiInstance.deleteContentLibraryDirectory(username, directory, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **directory** | **String**| Starting with the / following /content_library, this is the directory in {username} to create. This directory must not exist and, if it is a subdirectory, the parent directories must all exist. | 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="deleteContentLibraryFile"></a>
# **deleteContentLibraryFile**
> InlineResponse201 deleteContentLibraryFile(username, filePath, opts)



Delete a file.  {{ACL: User Email: Content Library}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.ContentLibraryApi

let username = "username_example"; // String | 
let filePath = "filePath_example"; // String | Required. Starting with the / following /content_library, this is the path of the file in {username} to delete.  The path must not end in a training slash. Be sure to not use double slashes.  Example: \"/files/media/image.jpg\".
let opts = { 
};
apiInstance.deleteContentLibraryFile(username, filePath, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **filePath** | **String**| Required. Starting with the / following /content_library, this is the path of the file in {username} to delete.  The path must not end in a training slash. Be sure to not use double slashes.  Example: \&quot;/files/media/image.jpg\&quot;. | 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getContentLibraryDirectory"></a>
# **getContentLibraryDirectory**
> InlineResponse20045 getContentLibraryDirectory(username, directory, opts)



Retrieve details about the specific Content Library directory. {{ACL: User Email: Content Library}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.ContentLibraryApi

let username = "username_example"; // String | 
let directory = "directory_example"; // String | Starting with the / following /content_library, this is the directory in {username} to examine.  The path must end in a training slash. Be sure to not use double slashes.  Note, for example, that for directory \"/files/media/\" you would insert \"files/media/\" in this variable. If this value is omitted, the contents of the top-level directory will be returned.
let opts = { 
};
apiInstance.getContentLibraryDirectory(username, directory, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **directory** | **String**| Starting with the / following /content_library, this is the directory in {username} to examine.  The path must end in a training slash. Be sure to not use double slashes.  Note, for example, that for directory \&quot;/files/media/\&quot; you would insert \&quot;files/media/\&quot; in this variable. If this value is omitted, the contents of the top-level directory will be returned. | 

### Return type

[**InlineResponse20045**](InlineResponse20045.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getContentLibraryFile"></a>
# **getContentLibraryFile**
> InlineResponse20046 getContentLibraryFile(username, filePath, opts)



Retrieve details about the specific Content Library file.  {{ACL: User Email: Content Library}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.ContentLibraryApi

let username = "username_example"; // String | 
let filePath = "filePath_example"; // String | Required. Starting with the / following /content_library, this is the path of the file in {username}.  The path must not end in a training slash. Be sure to not use double slashes.  Example: \"/files/media/image.jpg\".
let opts = { 
};
apiInstance.getContentLibraryFile(username, filePath, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **filePath** | **String**| Required. Starting with the / following /content_library, this is the path of the file in {username}.  The path must not end in a training slash. Be sure to not use double slashes.  Example: \&quot;/files/media/image.jpg\&quot;. | 

### Return type

[**InlineResponse20046**](InlineResponse20046.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="uploadContentLibraryFile"></a>
# **uploadContentLibraryFile**
> InlineResponse20046 uploadContentLibraryFile(username, filePath, opts)



Upload a new file to the Content Library.  {{ACL: User Email: Content Library}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.ContentLibraryApi

let username = "username_example"; // String | 
let filePath = "filePath_example"; // String | Required. Starting with the / following /content_library, this is the path in {username} to place the file.  The path must not end in a training slash. Be sure to not use double slashes. Example: \"files/media/image.jpg\".
let opts = { 
  'body': new Luxsci.ContentLibraryFilePathBody(), // ContentLibraryFilePathBody | 
};
apiInstance.uploadContentLibraryFile(username, filePath, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **filePath** | **String**| Required. Starting with the / following /content_library, this is the path in {username} to place the file.  The path must not end in a training slash. Be sure to not use double slashes. Example: \&quot;files/media/image.jpg\&quot;. | 
 **body** | [**ContentLibraryFilePathBody**](ContentLibraryFilePathBody.md)|  | [optional] 

### Return type

[**InlineResponse20046**](InlineResponse20046.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

