# Luxsci.ServersApi

All URIs are relative to *https://rest.luxsci.com/perl/api/v2*, unless a hostname is provided ([see README](../README.md#documentation-for-api-endpoints))

Method | HTTP request | Description
------------- | ------------- | -------------
[**getServerStatus**](ServersApi.md#getServerStatus) | **GET** /account/{accountId}/server/{serverId} | 
[**getServers**](ServersApi.md#getServers) | **GET** /account/{accountId}/servers | 
[**serverEmptyAllEmailQueues**](ServersApi.md#serverEmptyAllEmailQueues) | **DELETE** /account/{accountId}/server/{serverId}/sending_queues/all | 
[**serverEmptyEmailQueues**](ServersApi.md#serverEmptyEmailQueues) | **DELETE** /account/{accountId}/server/{serverId}/sending_queues | 
[**setServerSendngRate**](ServersApi.md#setServerSendngRate) | **POST** /account/{accountId}/server/{serverId}/sending_rate | 

<a name="getServerStatus"></a>
# **getServerStatus**
> InlineResponse20075 getServerStatus(accountId, serverId, opts)



This report allows you to retrieve specific current status of a specific server. This request will actually directly interrogate the server for some of this information; in situations where the server is overloaded or down or very slow, *this API will fail.*  {{ACL: Account: Servers - Report}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.ServersApi

let accountId = "accountId_example"; // String | 
let serverId = "serverId_example"; // String | Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id.
let opts = { 
};
apiInstance.getServerStatus(accountId, serverId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **serverId** | **String**| Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id. | 

### Return type

[**InlineResponse20075**](InlineResponse20075.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getServers"></a>
# **getServers**
> InlineResponse20074 getServers(accountId, opts)



This report allows you to retrieve general information about all of the dedicated servers associated with your account. {{ACL: Account: Servers - Report}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.ServersApi

let accountId = "accountId_example"; // String | 
let opts = { 
};
apiInstance.getServers(accountId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 

### Return type

[**InlineResponse20074**](InlineResponse20074.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="serverEmptyAllEmailQueues"></a>
# **serverEmptyAllEmailQueues**
> serverEmptyAllEmailQueues(accountId, serverId, opts)



This command allows you to remove all email messages that are queued.  These are the mail_queue_trying and mail_queue_unprocessed messages returned by the server status call.  Messages that have not yet been processed will be deleted by this call. 

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.ServersApi

let accountId = "accountId_example"; // String | 
let serverId = "serverId_example"; // String | Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id.
let opts = { 
};
apiInstance.serverEmptyAllEmailQueues(accountId, serverId, opts).then(() => {
  console.log('API called successfully.');
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **serverId** | **String**| Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id. | 

### Return type

null (empty response body)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

<a name="serverEmptyEmailQueues"></a>
# **serverEmptyEmailQueues**
> serverEmptyEmailQueues(accountId, serverId, opts)



This command allows you to remove all email messages that are queued and trying to be delivered to recipients.  These are the mail_queue_trying messages returned by the server status call.  Messages that have not yet been processed are not deleted. 

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.ServersApi

let accountId = "accountId_example"; // String | 
let serverId = "serverId_example"; // String | Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id.
let opts = { 
};
apiInstance.serverEmptyEmailQueues(accountId, serverId, opts).then(() => {
  console.log('API called successfully.');
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **serverId** | **String**| Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id. | 

### Return type

null (empty response body)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

<a name="setServerSendngRate"></a>
# **setServerSendngRate**
> setServerSendngRate(accountId, serverId, opts)



This command allows you to update the email processing rate limits for this server.  These rate limits govern the rate at which messages are processed and delivered to the queues for delivery to recipients, for IP Warmup purposes.  These settings to not impact messages already processed trying to be delivered to recipients.

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.ServersApi

let accountId = "accountId_example"; // String | 
let serverId = "serverId_example"; // String | Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id.
let opts = { 
  'body': new Luxsci.ServerIdSendingRateBody(), // ServerIdSendingRateBody | 
};
apiInstance.setServerSendngRate(accountId, serverId, opts).then(() => {
  console.log('API called successfully.');
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **serverId** | **String**| Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id. | 
 **body** | [**ServerIdSendingRateBody**](ServerIdSendingRateBody.md)|  | [optional] 

### Return type

null (empty response body)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: Not defined

